pub struct ZwpLinuxBufferParamsV1 { /* private fields */ }Expand description
parameters for creating a dmabuf-based wl_buffer
This temporary object is a collection of dmabufs and other parameters that together form a single logical buffer. The temporary object may eventually create one wl_buffer unless cancelled by destroying it before requesting ‘create’.
Single-planar formats only require one dmabuf, however multi-planar formats may require more than one dmabuf. For all formats, an ‘add’ request must be called once per plane (even if the underlying dmabuf fd is identical).
You must use consecutive plane indices (‘plane_idx’ argument for ‘add’) from zero to the number of planes used by the drm_fourcc format code. All planes required by the format must be given exactly once, but can be given in any order. Each plane index can only be set once; subsequent calls with a plane index which has already been set will result in a plane_set error being generated.
See also the Request enum for this interface.
Implementations
Sourceimpl ZwpLinuxBufferParamsV1
impl ZwpLinuxBufferParamsV1